CustomCacheManager class
Constructors
- CustomCacheManager({required String cacheDirName})
-
factory
Properties
- cacheDirName → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
cacheImage(
String url) → Future< File> -
clearCache(
) → Future< void> -
getImage(
String url) → Future< Map< String, dynamic> > -
isCacheCleared(
) → Future< bool> -
isCached(
String url) → Future< bool> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited